<?php
/**
 * 2007-2019 PrestaShop SA and Contributors
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2019 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 * International Registered Trademark & Property of PrestaShop SA
 */

namespace PrestaShop\PrestaShop\Core\Routing;

use PrestaShop\PrestaShop\Core\Routing\Exception\BuilderNotFoundException;

/**
 * Class EntityLinkBuilderFactory is able to return the builder for an entity.
 */
class EntityLinkBuilderFactory
{
    /**
     * @var EntityLinkBuilderInterface[]
     */
    private $builders;

    /**
     * @param array $builders
     */
    public function __construct(array $builders)
    {
        $this->builders = $builders;
    }

    /**
     * @param string $entity
     *
     * @return EntityLinkBuilderInterface
     *
     * @throws BuilderNotFoundException
     */
    public function getBuilderFor($entity)
    {
        foreach ($this->builders as $builder) {
            if ($builder->canBuild($entity)) {
                return $builder;
            }
        }

        throw new BuilderNotFoundException(sprintf('Can not find a builder for entity %s', $entity));
    }
}
